@@ -33,7 +33,8 @@
 #'
 #' @export
 #'
-MLLearnerBase <- R6::R6Class( # nolint
+MLLearnerBase <- R6::R6Class(
+  # nolint
   classname = "MLLearnerBase",
   public = list(
     #' @field cluster_export A character vector defining the (internal)
@@ -70,7 +71,7 @@ MLLearnerBase <- R6::R6Class( # nolint
     #'
     initialize = function(
       metric_optimization_higher_better # nolint
-      ) {
+    ) {
       stopifnot(
         "`metric_optimization_higher_better` must be a boolean value or \
         `NULL`" = is.logical(metric_optimization_higher_better) ||
@@ -114,7 +115,8 @@ MLLearnerBase <- R6::R6Class( # nolint
     cross_validation = function(...) {
       kwargs <- list(...)
       set.seed(self$seed)
-      do.call(private$fun_optim_cv, kwargs)
+      res <- do.call(private$fun_optim_cv, kwargs)
+      return(res)
     },
 
     #' @description
@@ -227,14 +229,14 @@ MLLearnerBase <- R6::R6Class( # nolint
     #'
     #' @return The results of the Bayesian scoring.
     #'
-    #' @seealso [ParBayesianOptimization::bayesOpt()],
+    #' @seealso [rBayesianOptimization::BayesianOptimization()],
     #'   [mlexperiments::MLTuneParameters], and [mlexperiments::MLNestedCV]
     #'
     #' @examples
     #' learner <- MLLearnerBase$new(metric_optimization_higher_better = FALSE)
     #' \dontrun{
     #' # This example cannot be run without further adaptions.
-    #' # The method `$bayesian_scoring_function()` needs to be overwritten when
+    #' # The method `$fun_bayesian_scoring_function()` needs to be overwritten when
     #' # inheriting from this class.
     #' learner$bayesian_scoring_function()
     #' }
@@ -242,19 +244,45 @@ MLLearnerBase <- R6::R6Class( # nolint
     bayesian_scoring_function = function(...) {
       kwargs <- list(...)
       args <- .method_params_refactor(
-        kwargs,
-        method_helper
+        params = kwargs,
+        method_helper = method_helper
       )
+
+      FUN <- private$fun_bayesian_scoring_function
+      environment(FUN) <- environment()
+
       set.seed(self$seed)
-      res <- do.call(private$fun_bayesian_scoring_function, args)
+      res <- do.call(FUN, args)
+
+      res_out <- list("Score" = res$Score)
 
       # take care of transforming results in case higher-better = FALSE
-      # --> bayesOpt tries to maximize the metric, so it is required to
+      # --> BayesianOptimization tries to maximize the metric, so it is required to
       # inverse score
       if (isFALSE(self$metric_optimization_higher_better)) {
-        res$Score <- as.numeric(I(res$Score * -1L))
+        res_out$Score <- as.numeric(I(res_out$Score * -1L))
       }
-      return(res)
+      # use Pred as vehicle, to pass other parameters from
+      # res (such as nrounds, which are optimized in lgb)
+      # to the return value from rBayesianOptimization
+      additional_vals <- setdiff(names(res), "Score")
+      if (length(additional_vals) > 0) {
+        # res_out$Pred <- sapply(
+        #   X = additional_vals,
+        #   FUN = function(x) {
+        #     res[[x]]
+        #   },
+        #   simplify = TRUE,
+        #   USE.NAMES = TRUE
+        # )
+        res_out$Pred <- data.table::as.data.table(
+          res[additional_vals]
+        )
+      } else {
+        res_out$Pred <- 0L
+      }
+      #browser()
+      return(res_out)
     }
   ),
   private = list(
