@@ -20,74 +20,80 @@
 #'   across all folds.
 #'
 #' @examples
-#' dataset <- do.call(
-#'   cbind,
-#'   c(sapply(paste0("col", 1:6), function(x) {
-#'     rnorm(n = 500)
-#'     },
-#'     USE.NAMES = TRUE,
-#'     simplify = FALSE
-#'    ),
-#'    list(target = sample(0:1, 500, TRUE))
-#' ))
+#' if (requireNamespace("measures", quietly = TRUE)) {
+#'   dataset <- do.call(
+#'     cbind,
+#'     c(sapply(paste0("col", 1:6), function(x) {
+#'       rnorm(n = 500)
+#'       },
+#'       USE.NAMES = TRUE,
+#'       simplify = FALSE
+#'      ),
+#'      list(target = sample(0:1, 500, TRUE))
+#'   ))
 #'
-#' fold_list <- splitTools::create_folds(
-#'   y = dataset[, 7],
-#'   k = 3,
-#'   type = "stratified",
-#'   seed = 123
-#' )
+#'   fold_list <- splitTools::create_folds(
+#'     y = dataset[, 7],
+#'     k = 3,
+#'     type = "stratified",
+#'     seed = 123
+#'   )
 #'
-#' glm_optimization <- mlexperiments::MLCrossValidation$new(
-#'   learner = LearnerGlm$new(),
-#'   fold_list = fold_list,
-#'   seed = 123
-#' )
+#'   glm_optimization <- mlexperiments::MLCrossValidation$new(
+#'     learner = LearnerGlm$new(),
+#'     fold_list = fold_list,
+#'     seed = 123
+#'   )
 #'
-#' glm_optimization$learner_args <- list(family = binomial(link = "logit"))
-#' glm_optimization$predict_args <- list(type = "response")
-#' glm_optimization$performance_metric_args <- list(
-#'    positive = 1,
-#'    negative =0
-#' )
-#' glm_optimization$performance_metric <- metric("AUC")
-#' glm_optimization$return_models <- TRUE
+#'   glm_optimization$learner_args <- list(family = binomial(link = "logit"))
+#'   glm_optimization$predict_args <- list(type = "response")
+#'   glm_optimization$performance_metric_args <- list(
+#'      positive = 1,
+#'      negative =0
+#'   )
+#'   glm_optimization$performance_metric <- metric("AUC")
+#'   glm_optimization$return_models <- TRUE
 #'
-#' # set data
-#' glm_optimization$set_data(
-#'   x = data.matrix(dataset[, -7]),
-#'   y = dataset[, 7]
-#' )
+#'   # set data
+#'   glm_optimization$set_data(
+#'     x = data.matrix(dataset[, -7]),
+#'     y = dataset[, 7]
+#'   )
 #'
-#' cv_results <- glm_optimization$execute()
+#'   cv_results <- glm_optimization$execute()
 #'
-#' # predictions
-#' preds <- mlexperiments::predictions(
-#'   object = glm_optimization,
-#'   newdata = data.matrix(dataset[, -7]),
-#'   na.rm = FALSE,
-#'   ncores = 2L,
-#'   type = "response"
-#' )
-#' head(preds)
+#'   # predictions
+#'   preds <- mlexperiments::predictions(
+#'     object = glm_optimization,
+#'     newdata = data.matrix(dataset[, -7]),
+#'     na.rm = FALSE,
+#'     ncores = 2L,
+#'     type = "response"
+#'   )
+#'   head(preds)
+#' }
 #'
 #' @export
 #'
 predictions <- function(
-    object,
-    newdata,
-    na.rm = FALSE, # nolint
-    ncores = -1L,
-    ...
-  ) {
+  object,
+  newdata,
+  na.rm = FALSE, # nolint
+  ncores = -1L,
+  ...
+) {
   stopifnot(
     "`ncores` must be an integer" = is.integer(as.integer(ncores)),
     "`ncores` must not be `0L`" = ncores != 0L,
-    "`object` must be of class `MLCrossValidation`" =
-      inherits(object, what = "MLCrossValidation"),
+    "`object` must be of class `MLCrossValidation`" = inherits(
+      object,
+      what = "MLCrossValidation"
+    ),
     "`object` must be an R6-class" = R6::is.R6(object),
-    "`object$results` must be of class `mlexCV`" =
-      inherits(object$results, "mlexCV"),
+    "`object$results` must be of class `mlexCV`" = inherits(
+      object$results,
+      "mlexCV"
+    ),
     "`object$return_models` must be `TRUE`" = isTRUE(object$return_models),
     "`na.rm` must be a boolean value" = is.logical(na.rm)
   )
@@ -102,8 +108,9 @@ predictions <- function(
       newdata = newdata,
       ncores = ncores
     ),
-    append_list =
-      object$.__enclos_env__$private$method_helper$execute_params["cat_vars"]
+    append_list = object$.__enclos_env__$private$method_helper$execute_params[
+      "cat_vars"
+    ]
   )
   # add kwargs
   pred_args_base <- kdry::list.append(
@@ -132,9 +139,10 @@ predictions <- function(
 
   res <- data.table::as.data.table(res_pre)
 
-  res[, `:=`(
-    mean = mean(as.numeric(.SD), na.rm = na.rm),
-    sd = stats::sd(as.numeric(.SD), na.rm = na.rm)
+  res[,
+    `:=`(
+      mean = mean(as.numeric(.SD), na.rm = na.rm),
+      sd = stats::sd(as.numeric(.SD), na.rm = na.rm)
     ),
     .SDcols = colnames(res),
     by = seq_len(nrow(res))
