@@ -12,8 +12,11 @@
   # init a progress bar
   pb <- progress::progress_bar$new(
     format = "\nParameter settings [:bar] :current/:total (:percent)",
-    total = ngrid
+    total = ngrid,
+    force = TRUE
   )
+  
+  FUN <- self$learner$cross_validation # nolint
 
   optim_results <- lapply(
     X = seq_len(ngrid),
@@ -44,11 +47,6 @@
         method_helper
       )
 
-      # FUN <- eval(parse(text = paste0(
-      #   private$method, "_cv"
-      # )))
-      FUN <- self$learner$cross_validation # nolint
-
       fun_parameters <- list(
         "x" = x,
         "y" = y,
@@ -57,7 +55,6 @@
         "ncores" = private$ncores,
         "seed" = private$seed
       )
-
       set.seed(private$seed)
       fit_grid <- do.call(FUN, fun_parameters)
 
@@ -66,6 +63,11 @@
         params$case_weights <- NULL
       }
 
+      # remove cat_vars from params, otherwise displaying is very strange
+      if ("cat_vars" %in% names(params)) {
+        params$cat_vars <- NULL
+      }
+
       ret <- data.table::as.data.table(
         c(
           list("setting_id" = setting_id),
