@@ -43,6 +43,9 @@ test_that(
   desc = "test cv - knn",
   code = {
 
+    testthat::skip_if_not_installed("class")
+    testthat::skip_if_not_installed("measures")
+
     knn_optimization <- mlexperiments::MLCrossValidation$new(
       learner = LearnerKnn$new(),
       fold_list = fold_list,
@@ -82,7 +85,7 @@ test_that(
 
 knn_bounds <- list(k = c(2L, 80L))
 optim_args <- list(
-  iters.n = ncores,
+  n_iter = ncores,
   kappa = 3.5,
   acq = "ucb"
 )
@@ -93,9 +96,12 @@ param_list_knn <- expand.grid(
 )
 
 test_that(
-  desc = "test bayesian tuner, initGrid - knn",
+  desc = "test bayesian tuner, init_grid_dt - knn",
   code = {
 
+    testthat::skip_if_not_installed("class")
+    testthat::skip_if_not_installed("rBayesianOptimization")
+
     knn_optimization <- mlexperiments::MLTuneParameters$new(
       learner = LearnerKnn$new(),
       strategy = "bayesian",
@@ -149,18 +155,18 @@ test_that(
       what = "mlexTune"
     ))
 
-    expect_equal(
-      cv_results1[, .SD, .SDcols = !"Elapsed"],
-      cv_results2[, .SD, .SDcols = !"Elapsed"]
-    )
+    expect_equal(cv_results1, cv_results2)
   }
 )
 
 
 test_that(
-  desc = "test bayesian tuner, initPoints - LearnerKnn",
+  desc = "test bayesian tuner, init_points - LearnerKnn",
   code = {
 
+    testthat::skip_if_not_installed("class")
+    testthat::skip_if_not_installed("rBayesianOptimization")
+
     knn_optimization <- mlexperiments::MLTuneParameters$new(
       learner = LearnerKnn$new(),
       strategy = "bayesian",
@@ -193,6 +199,8 @@ test_that(
   desc = "test grid tuner - knn",
   code = {
 
+    testthat::skip_if_not_installed("class")
+
     knn_optimization <- mlexperiments::MLTuneParameters$new(
       learner = LearnerKnn$new(),
       strategy = "grid",
@@ -230,6 +238,10 @@ test_that(
   desc = "test nested cv, bayesian - knn",
   code = {
 
+    testthat::skip_if_not_installed("class")
+    testthat::skip_if_not_installed("measures")
+    testthat::skip_if_not_installed("rBayesianOptimization")
+
     knn_optimization <- mlexperiments::MLNestedCV$new(
       learner = LearnerKnn$new(),
       strategy = "bayesian",
@@ -269,6 +281,9 @@ test_that(
   desc = "test nested cv, grid - knn",
   code = {
 
+    testthat::skip_if_not_installed("class")
+    testthat::skip_if_not_installed("measures")
+
     knn_optimization <- mlexperiments::MLNestedCV$new(
       learner = LearnerKnn$new(),
       strategy = "grid",
