@@ -44,6 +44,9 @@ test_that(
   desc = "test cv, regression - rpart",
   code = {
 
+    testthat::skip_if_not_installed("rpart")
+    testthat::skip_if_not_installed("measures")
+
     rpart_optimization <- mlexperiments::MLCrossValidation$new(
       learner = LearnerRpart$new(),
       fold_list = fold_list,
@@ -88,7 +91,7 @@ rpart_bounds <- list(
   maxdepth = c(2L, 30L)
 )
 optim_args <- list(
-  iters.n = ncores,
+  n_iter = ncores,
   kappa = 3.5,
   acq = "ucb"
 )
@@ -102,6 +105,9 @@ test_that(
   desc = "test bayesian tuner, initGrid, regression - rpart",
   code = {
 
+    testthat::skip_if_not_installed("rpart")
+    testthat::skip_if_not_installed("rBayesianOptimization")
+
     rpart_optimization <- mlexperiments::MLTuneParameters$new(
       learner = LearnerRpart$new(),
       strategy = "bayesian",
@@ -135,6 +141,8 @@ test_that(
   desc = "test grid tuner, regression - rpart",
   code = {
 
+    testthat::skip_if_not_installed("rpart")
+
     rpart_optimization <- mlexperiments::MLTuneParameters$new(
       learner = LearnerRpart$new(),
       strategy = "grid",
@@ -175,6 +183,10 @@ test_that(
   desc = "test nested cv, bayesian, regression - rpart",
   code = {
 
+    testthat::skip_if_not_installed("rpart")
+    testthat::skip_if_not_installed("measures")
+    testthat::skip_if_not_installed("rBayesianOptimization")
+
     rpart_optimization <- mlexperiments::MLNestedCV$new(
       learner = LearnerRpart$new(),
       strategy = "bayesian",
@@ -215,6 +227,9 @@ test_that(
   desc = "test nested cv, grid, regression - rpart",
   code = {
 
+    testthat::skip_if_not_installed("rpart")
+    testthat::skip_if_not_installed("measures")
+
     rpart_optimization <- mlexperiments::MLNestedCV$new(
       learner = LearnerRpart$new(),
       strategy = "grid",
